@@ -24,7 +24,9 @@
 #include "rfccodecs.h"
 #include "kimap_debug.h"
 
-namespace KIMAP2
+#include <KLocalizedString>
+
+namespace KIMAP
 {
 
 class StatusJobPrivate : public JobPrivate
@@ -46,10 +48,10 @@ public:
 
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 StatusJob::StatusJob(Session *session)
-    : Job(*new StatusJobPrivate(session, "Status"))
+    : Job(*new StatusJobPrivate(session, i18nc("name of the status job", "Status")))
 {
 }
 
@@ -91,10 +93,10 @@ void StatusJob::doStart()
 {
     Q_D(StatusJob);
 
-    const QByteArray params = '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + "\" ("
+    const QByteArray params = '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + "\" ("
                             + d->dataItems.join(' ') + ')';
 
-    d->sendCommand("STATUS", params);
+    d->tags << d->sessionInternal()->sendCommand("STATUS", params);
 }
 
 void StatusJob::handleResponse(const Message &response)
@@ -114,8 +116,10 @@ void StatusJob::handleResponse(const Message &response)
             } else if (code == "OK") {
                 return;
             } else {
-                qCDebug(KIMAP2_LOG) << response.toString();
+                qCDebug(KIMAP_LOG) << response.toString();
             }
         }
+    } else {
+        Q_ASSERT(error());
     }
 }
